@@ -4,7 +4,7 @@ from pydantic import BaseModel, Field
 from typing import List, Optional
 
 from .. import compress_sequential
-from ..common import compress
+from liteauto.utils.common import compress
 
 
 class PaperInsights(BaseModel):
@@ -95,7 +95,7 @@ def research_paper_analysis(pdf_path_or_url,compress_paralle=True):
     l5 = compress_func(l4)
     abs_insights = llm(f'given research paper abstract generate insights, Abstract : {abs}',
                        response_format=PaperInsights)
-    summary_insights = llm(f'given research paper summary generate insights, Summary : {l5}',
+    summary_insights = llm(f'given research paper summary generate insights, Summary : {l4}',
                            response_format=SummaryInsights)
 
     paper = ResearchPaperAnalysis(
