@@ -214,7 +214,7 @@ def main():
                             st.session_state.search_results,
                             allow_pdf_extraction=allow_pdf,
                             allow_youtube_urls_extraction=allow_youtube,
-                            arxiv_html_flag=allow_arxiv
+                            only_abstract=allow_arxiv
                         )
                         st.write("Parsed Content:")
                         for result in results:
